package com.ruoyi.project.business.service;

import com.ruoyi.common.importExcel.excel.helper.BasicExcelHelper;
import com.ruoyi.common.importExcel.excel.helper.BasicTableInfoHelper;
import com.ruoyi.common.importExcel.excel.tempInfo.ElevatorParaInfoHelper;
import com.ruoyi.common.importExcel.excel.tempInfo.ParaLibraryExcel;
import com.ruoyi.common.importExcel.utils.ExcelUtils.*;
import com.ruoyi.project.business.domain.TpAreaElevatorModelPara;
import com.ruoyi.project.business.domain.vo.paramSelectItem.ElevatorModeParamlVo;

import java.util.Collection;
import java.util.List;


/**
 * 【请填写功能名称】Service接口
 * 
 * @author ruoyi
 * @date 2024-04-25
 */
public interface ITpAreaElevatorModelParaService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TpAreaElevatorModelPara selectTpAreaElevatorModelParaById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tpAreaElevatorModelPara 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TpAreaElevatorModelPara> selectTpAreaElevatorModelParaList(TpAreaElevatorModelPara tpAreaElevatorModelPara);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tpAreaElevatorModelPara 【请填写功能名称】
     * @return 结果
     */
    public int insertTpAreaElevatorModelPara(TpAreaElevatorModelPara tpAreaElevatorModelPara);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tpAreaElevatorModelPara 【请填写功能名称】
     * @return 结果
     */
    public int updateTpAreaElevatorModelPara(TpAreaElevatorModelPara tpAreaElevatorModelPara);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTpAreaElevatorModelParaByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTpAreaElevatorModelParaById(Long id);


    UploadResult<ElevatorParaInfoHelper> checkElevatorParaInfo(BasicTableInfoHelper tableInfo, List<ElevatorParaInfoHelper> list);

    List<String> insertElevatorModelParaExcel(BasicTableInfoHelper basicTableInfoHelper, List<ElevatorParaInfoHelper> transform);

    String updateModelParam(ElevatorModeParamlVo paramlVo);

    List<List<? extends BasicExcelHelper>> elevatorModelExcel(Long elevatorModelIds);

    UploadResult<ParaLibraryExcel> checkElevatorParaInfoNew(BasicTableInfoHelper tableInfo, List<ParaLibraryExcel> list);

    List<String> insertElevatorModelParaExcelNew(BasicTableInfoHelper basicTableInfoHelper, List<ParaLibraryExcel> transform);

}
