package com.ruoyi.project.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.framework.annotation.DataUpdateCheck;
import com.ruoyi.project.business.domain.TpAreaElevatorModelPara;
import com.ruoyi.project.business.domain.vo.paramSelectItem.ElevatorModeParamlVo;
import com.ruoyi.project.business.service.ITpAreaElevatorModelParaService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-04-25
 */
@RestController
@RequestMapping("/business/elevatorPara")
public class TpAreaElevatorModelParaController extends BaseController
{
    @Autowired
    private ITpAreaElevatorModelParaService tpAreaElevatorModelParaService;

    /**
     * 查询【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:para:list')")
    @GetMapping("/list")
    public TableDataInfo list(TpAreaElevatorModelPara tpAreaElevatorModelPara)
    {
        startPage();
        List<TpAreaElevatorModelPara> list = tpAreaElevatorModelParaService.selectTpAreaElevatorModelParaList(tpAreaElevatorModelPara);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    // @PreAuthorize("@ss.hasPermi('system:para:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TpAreaElevatorModelPara tpAreaElevatorModelPara)
    {
        List<TpAreaElevatorModelPara> list = tpAreaElevatorModelParaService.selectTpAreaElevatorModelParaList(tpAreaElevatorModelPara);
        ExcelUtil<TpAreaElevatorModelPara> util = new ExcelUtil<TpAreaElevatorModelPara>(TpAreaElevatorModelPara.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    // @PreAuthorize("@ss.hasPermi('system:para:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tpAreaElevatorModelParaService.selectTpAreaElevatorModelParaById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:para:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TpAreaElevatorModelPara tpAreaElevatorModelPara)
    {
        return toAjax(tpAreaElevatorModelParaService.insertTpAreaElevatorModelPara(tpAreaElevatorModelPara));
    }

    /**
     * 修改【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:para:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TpAreaElevatorModelPara tpAreaElevatorModelPara)
    {
        return toAjax(tpAreaElevatorModelParaService.updateTpAreaElevatorModelPara(tpAreaElevatorModelPara));
    }

    /**
     * 删除【请填写功能名称】
     */
    // @PreAuthorize("@ss.hasPermi('system:para:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tpAreaElevatorModelParaService.deleteTpAreaElevatorModelParaByIds(ids));
    }


    /**
     * 新增或修改梯形参数数据
     */
    // @PreAuthorize("@ss.hasPermi('business:modelPara:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PostMapping("/updateModelParam")
    @DataUpdateCheck(key = "id", tableName = "tp_elevator_model")
    public AjaxResult editParam(@RequestBody ElevatorModeParamlVo paramlVo)
    {
        String res = tpAreaElevatorModelParaService.updateModelParam(paramlVo);
        if(StringUtils.isEmpty(res)){
           return AjaxResult.success();
        }
        return AjaxResult.error();
    }
}
